@@ -5,7 +5,6 @@
  *                            | (__| |_| |  _ <| |___
  *                             \___|\___/|_| \_\_____|
  *
- * $Id: sepheaders.c,v 1.9 2007-07-16 21:22:12 danf Exp $
  */
 
 #include <stdio.h>
@@ -36,10 +35,10 @@ int main(int argc, char **argv)
   curl_handle = curl_easy_init();
 
   /* set URL to get */
-  curl_easy_setopt(curl_handle, CURLOPT_URL, "http://curl.haxx.se");
+  curl_easy_setopt(curl_handle, CURLOPT_URL, "http://example.com");
 
   /* no progress meter please */
-  curl_easy_setopt(curl_handle, CURLOPT_NOPROGRESS, 1);
+  curl_easy_setopt(curl_handle, CURLOPT_NOPROGRESS, 1L);
 
   /* send all data to this function  */
   curl_easy_setopt(curl_handle, CURLOPT_WRITEFUNCTION, write_data);
@@ -57,7 +56,7 @@ int main(int argc, char **argv)
   }
 
   /* we want the headers to this file handle */
-  curl_easy_setopt(curl_handle,   CURLOPT_WRITEHEADER ,headerfile);
+  curl_easy_setopt(curl_handle,   CURLOPT_WRITEHEADER, headerfile);
 
   /*
    * Notice here that if you want the actual data sent anywhere else but
