@@ -83,6 +83,7 @@
 
 #include <curl/curl.h>
 #include "rawstr.h"
+#include "warnless.h"
 #include "parsedate.h"
 
 const char * const Curl_wkday[] =
@@ -371,8 +372,14 @@ int Curl_parsedate(const char *date, time_t *output)
         /* time stamp! */
         date += 8;
       }
+      else if((secnum == -1) &&
+              (2 == sscanf(date, "%02d:%02d", &hournum, &minnum))) {
+        /* time stamp without seconds */
+        date += 5;
+        secnum = 0;
+      }
       else {
-        val = (int)strtol(date, &end, 10);
+        val = curlx_sltosi(strtol(date, &end, 10));
 
         if((tzoff == -1) &&
            ((end - date) == 4) &&
